==> openshift-model-monitoring-5.10.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/WebSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WebSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.WebSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.WebSpec,io.fabric8.openshift.api.model.monitoring.v1.WebSpecBuilder>{
  public WebSpecBuilder() {
    this(false);
  }
  public WebSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new WebSpec(), validationEnabled);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WebSpec(), validationEnabled);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance) {
    this(fluent, instance, false);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPageTitle(instance.getPageTitle()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance) {
    this(instance,false);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPageTitle(instance.getPageTitle()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.WebSpec build() {
    WebSpec buildable = new WebSpec(fluent.getPageTitle());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WebSpecBuilder that = (WebSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1/WebSpecBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class WebSpecBuilder extends io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluentImpl<io.fabric8.openshift.api.model.monitoring.v1.WebSpecBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1.WebSpec,io.fabric8.openshift.api.model.monitoring.v1.WebSpecBuilder>{
  public WebSpecBuilder() {
    this(false);
  }
  public WebSpecBuilder(java.lang.Boolean validationEnabled) {
    this(new WebSpec(), validationEnabled);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent) {
    this(fluent, false);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new WebSpec(), validationEnabled);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance) {
    this(fluent, instance, false);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withPageTitle(instance.getPageTitle()); 
    fluent.withTlsConfig(instance.getTlsConfig()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance) {
    this(instance,false);
  }
  public WebSpecBuilder(io.fabric8.openshift.api.model.monitoring.v1.WebSpec instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withPageTitle(instance.getPageTitle()); 
    this.withTlsConfig(instance.getTlsConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1.WebSpecFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1.WebSpec build() {
    WebSpec buildable = new WebSpec(fluent.getPageTitle(),fluent.getTlsConfig());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    WebSpecBuilder that = (WebSpecBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
